==> haskell-hslua-core-2.1.0-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-core
version:              2.1.0
visibility:           public
id:                   hslua-core-2.1.0-3FRz0n2z0ob6x88v7baw1R
key:                  hslua-core-2.1.0-3FRz0n2z0ob6x88v7baw1R
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2022 Albert Krewinkel

maintainer:           albert+hslua@zeitkraut.de
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Bindings to Lua, an embeddable scripting language
description:
    Wrappers and helpers to bridge Haskell and
    <https://www.lua.org/ Lua>.

    It builds upon the /lua/ package, which allows to bundle
    a Lua interpreter with a Haskell program.

category:             Foreign
abi:                  1460dca3cd22e37edfdffc5012610c35
exposed:              True
exposed-modules:
    HsLua.Core, HsLua.Core.Closures, HsLua.Core.Error,
    HsLua.Core.Package, HsLua.Core.Run, HsLua.Core.Trace,
    HsLua.Core.Types, HsLua.Core.Unsafe, HsLua.Core.Userdata,
    HsLua.Core.Utf8, Lua from lua-2.1.0-ILxlszNCDkmJHCGvdyAymr:Lua

hidden-modules:       HsLua.Core.Auxiliary HsLua.Core.Primary
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hslua-core-2.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hslua-core-2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-core
hs-libraries:         HShslua-core-2.1.0-3FRz0n2z0ob6x88v7baw1R
depends:
    base-4.15.1.0 bytestring-0.10.12.1 exceptions-0.10.4
    lua-2.1.0-ILxlszNCDkmJHCGvdyAymr mtl-2.2.2 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-hslua-core/html/hslua-core.haddock
haddock-html:         /usr/share/doc/haskell-hslua-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-core-2.1.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-core
version:              2.1.0
visibility:           public
id:                   hslua-core-2.1.0-6jFHRva9WSvHLqA5p5zU0m
key:                  hslua-core-2.1.0-6jFHRva9WSvHLqA5p5zU0m
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2022 Albert Krewinkel

maintainer:           albert+hslua@zeitkraut.de
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Bindings to Lua, an embeddable scripting language
description:
    Wrappers and helpers to bridge Haskell and
    <https://www.lua.org/ Lua>.

    It builds upon the /lua/ package, which allows to bundle
    a Lua interpreter with a Haskell program.

category:             Foreign
abi:                  82f3f0fbbd436ed4fcab0048e96b5400
exposed:              True
exposed-modules:
    HsLua.Core, HsLua.Core.Closures, HsLua.Core.Error,
    HsLua.Core.Package, HsLua.Core.Run, HsLua.Core.Trace,
    HsLua.Core.Types, HsLua.Core.Unsafe, HsLua.Core.Userdata,
    HsLua.Core.Utf8, Lua from lua-2.1.0-GTd5ts8Ys3d5KXfbA0nOat:Lua

hidden-modules:       HsLua.Core.Auxiliary HsLua.Core.Primary
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hslua-core-2.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hslua-core-2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-core
hs-libraries:         HShslua-core-2.1.0-6jFHRva9WSvHLqA5p5zU0m
depends:
    base-4.15.1.0 bytestring-0.10.12.1 exceptions-0.10.4
    lua-2.1.0-GTd5ts8Ys3d5KXfbA0nOat mtl-2.2.2 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-hslua-core/html/hslua-core.haddock
haddock-html:         /usr/share/doc/haskell-hslua-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
